summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KXMLGUIFactory.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KXMLGUIFactory.java')
-rw-r--r--kdejava/koala/org/kde/koala/KXMLGUIFactory.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdejava/koala/org/kde/koala/KXMLGUIFactory.java b/kdejava/koala/org/kde/koala/KXMLGUIFactory.java
index 80da94a4..09b260d7 100644
--- a/kdejava/koala/org/kde/koala/KXMLGUIFactory.java
+++ b/kdejava/koala/org/kde/koala/KXMLGUIFactory.java
@@ -20,7 +20,7 @@ import org.kde.qt.TQObject;
actions. KXMLGUIFactory takes care of building (with the help of a KXMLGUIBuilder)
and merging the GUI from an unlimited number of clients.
Each client provides XML through a TQDomDocument and actions through a
- KActionCollection . The XML document contains the rules for how to merge the
+ TDEActionCollection . The XML document contains the rules for how to merge the
GUI.
KXMLGUIFactory processes the DOM tree provided by a client and plugs in the client's actions,
according to the XML and the merging rules of previously inserted clients. Container widgets
@@ -74,7 +74,7 @@ public class KXMLGUIFactory extends TQObject {
@short Removes the GUI described by the client, by unplugging all provided actions and removing all owned containers (and storing container state information in the given client)
*/
public native void removeClient(KXMLGUIClientInterface client);
// void plugActionList(KXMLGUIClient* arg1,const TQString& arg2,const TQPtrList<KAction>& arg3); >>>> NOT CONVERTED
public native void unplugActionList(KXMLGUIClientInterface client, String name);
/**
Returns a list of all clients currently added to this factory
@@ -74,7 +74,7 @@ public class KXMLGUIFactory extends TQObject {
*/
public native void removeClient(KXMLGUIClientInterface client);
- // void plugActionList(KXMLGUIClient* arg1,const TQString& arg2,const TQPtrList<KAction>& arg3); >>>> NOT CONVERTED
+ // void plugActionList(KXMLGUIClient* arg1,const TQString& arg2,const TQPtrList<TDEAction>& arg3); >>>> NOT CONVERTED
public native void unplugActionList(KXMLGUIClientInterface client, String name);
/**